// -*- c++ -*-

#ifndef KFORMS_H
#define KFORMS_H

#include <qdom.h>
#include <kdialogbase.h>

namespace KForms {

/**
 * Loads dialogs from an XML definition.
 *
 * @author Richard Moore, rich@kde.org
 * @version $Id: kforms.h,v 1.2 2002/03/11 02:08:49 rich Exp $
 */
class Builder
{
public:
    Builder();
    ~Builder();

    bool load( const QString &filename );

    KDialogBase *dialog() const { return dlg; }

protected:
    // Walk DOM Tree
    void walkDocument();
    void walkElement( const QDomElement &elem );
    void processElement( const QDomElement &elem );

    // Process Tag
    void processDialog( const QDomElement &elem );
    void processPage( const QDomElement &elem );
    void processForm( const QDomElement &elem );
    void processLabel( const QDomElement &elem );
    void processField( const QDomElement &elem );
    void processSpacer( const QDomElement &elem );

    // Utils
    KDialogBase::ButtonCode buttonId( const QString &name );
    int processButtons( const QDomElement &elem, KDialogBase::ButtonCode &def );
    QString findText( const QDomElement &elem, const QString &tag );

private:
    QDomDocument doc;
    KDialogBase *dlg;
    QWidget *parent;
};

}; // namespace KForms

#endif // KFORMS_H

// Local Variables:
// c-basic-offset: 4
// End:
